@@ -55,13 +55,17 @@ class Customer(object):
             self.table_cdr = 'cdr'
         conn = core.connexion(**FUPDB_CREDENTIALS)
         cursor = conn.cursor()
+        # sql = (
+        #     "select refnum, product"
+        #     " from {} where name = %s"
+        #     ).format(self.table_customer)
         sql = (
             "select refnum, product"
-            " from {} where name = %s"
-            ).format(self.table_customer)
+            " from customer where name = %s"
+            )
         cursor.execute(sql, (self.name,))
         row = cursor.fetchone()
-        LOGS.logger.info("Resutlt: {}".format(row))
+        LOGS.logger.info("Result for {}: {}".format(self.name, row))
         if not row:
             raise ValueError(
                 "Le client {name} n'existe pas".format(name=name)
